@@ -18,48 +18,27 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#define TRUE 1
-#define FALSE 0
-
 #define YES "Yes"
 #define NO  "No"
 
 #include "../../configure.h"
 
-#include <stdio.h>
-#include <signal.h>
-#include <fcntl.h>
-#include <string.h>
-#include <unistd.h>
-#include <ctype.h>
 #include <stdlib.h>
-#include <sys/wait.h>
-#include <sys/time.h>
-#if defined ___AIX || defined _AIX || defined __QNX__ || defined ___AIXV3 || defined AIXV3 || defined _SEQUENT_
-#include <sys/select.h>
-#endif
+
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <X11/Xproto.h>
-#include <X11/Xatom.h>
-#include <X11/Intrinsic.h>
 #include <X11/cursorfont.h>
 #include <X11/Xmu/WinUtil.h>
 
+#define IN_MODULE
+#define MODULE_X_INTERFACE
 #include "../../include/aftersteplib.h"
 #include "../../include/module.h"
 #include "Scroll.h"
 
-char *MyName;
-int fd_width;
 int fd[2];
 
-Display *dpy;			/* which display are we talking to */
-Window Root;
-int screen;
-int x_fd;
-int d_depth;
-int ScreenWidth, ScreenHeight;
+ScreenInfo Scr;
 
 char *BackColor = "black";
 char *ForeColor = "grey";
@@ -81,7 +60,7 @@ void
 usage (void)
 {
   printf ("Usage:\n"
-	  "%s [--version] [--help] [--window window-id] [x y]\n", MyName);
+	  "%s [-v|--version] [-h|--help] [--window window-id] [x y]\n", MyName);
   exit (0);
 }
 
@@ -103,6 +82,7 @@ main (int argc, char **argv)
   /* Save our program name - for error messages */
   temp = strrchr (argv[0], '/');
   MyName = temp ? temp + 1 : argv[0];
+  set_application_name( argv[0] );
 
   for (i = 1; i < argc && *argv[i] == '-'; i++)
     {
@@ -120,28 +100,11 @@ main (int argc, char **argv)
 
   /* Dead pipe == dead AfterStep */
   signal (SIGPIPE, DeadPipe);
+  set_signal_handler (SIGSEGV);
 
-  if ((dpy = XOpenDisplay ("")) == NULL)
-    {
-      fprintf (stderr, "%s: couldn't open display %s\n",
-	       MyName, XDisplayName (""));
-      exit (1);
-    }
-  screen = DefaultScreen (dpy);
-
+  x_fd = ConnectX( &Scr, display_name, 0 );
   /* connect to AfterStep */
-  temp = module_get_socket_property (RootWindow (dpy, screen));
-  fd[0] = fd[1] = module_connect (temp);
-  XFree (temp);
-  if (fd[0] < 0)
-    {
-      fprintf (stderr, "%s: unable to establish connection to AfterStep\n", MyName);
-      exit (1);
-    }
-  temp = safemalloc (9 + strlen (MyName) + 1);
-  sprintf (temp, "SET_NAME %s", MyName);
-  SendInfo (fd, temp, None);
-  free (temp);
+  fd[0] = fd[1] = ConnectAfterStep (0);
 
   if (i < argc)
     {
@@ -155,13 +118,6 @@ main (int argc, char **argv)
 	Reduction_V = 2;
     }
 
-  x_fd = XConnectionNumber (dpy);
-  Root = RootWindow (dpy, screen);
-  d_depth = DefaultDepth (dpy, screen);
-
-  ScreenHeight = DisplayHeight (dpy, screen);
-  ScreenWidth = DisplayWidth (dpy, screen);
-
   /* scan config file for set-up parameters */
   /* Colors and fonts */
   if (global_config_file != NULL)
@@ -216,9 +172,9 @@ ParseOptions (const char *filename)
 	    {
 	      tline += len + 1;
 	      if (!mystrncasecmp (tline, "Fore", 4))
-		CopyString (&ForeColor, tline + 4);
+        ForeColor = stripcpy( tline + 4);
 	      else if (!mystrncasecmp (tline, "Back", 4))
-		CopyString (&BackColor, tline + 4);
+        BackColor = stripcpy( tline + 4);
 	    }
 	}
       free (line);
@@ -228,7 +184,7 @@ ParseOptions (const char *filename)
 
 /***********************************************************************
  *
- * Detected a broken pipe - time to exit 
+ * Detected a broken pipe - time to exit
  *
  **********************************************************************/
 void
@@ -236,8 +192,8 @@ DeadPipe (int nonsense)
 {
   extern Atom wm_del_win;
 
-  XReparentWindow (dpy, app_win, Root, 0, 0);
-  send_clientmessage (app_win, wm_del_win, CurrentTime);
+  XReparentWindow (dpy, app_win, Scr.Root, 0, 0);
+  send_wm_protocol_request(app_win, wm_del_win, CurrentTime);
   XSync (dpy, 0);
   exit (0);
 }
@@ -246,7 +202,7 @@ DeadPipe (int nonsense)
 /**********************************************************************
  *
  * If no application window was indicated on the command line, prompt
- * the user to select one 
+ * the user to select one
  *
  *********************************************************************/
 void
@@ -259,7 +215,7 @@ GetTargetWindow (Window * app_win)
   trials = 0;
   while ((trials < 100) && (val != GrabSuccess))
     {
-      val = XGrabPointer (dpy, Root, True,
+      val = XGrabPointer (dpy, Scr.Root, True,
 			  ButtonReleaseMask,
 			  GrabModeAsync, GrabModeAsync, Root,
 			  XCreateFontCursor (dpy, XC_crosshair),
@@ -288,18 +244,10 @@ GetTargetWindow (Window * app_win)
 }
 
 
-void
-nocolor (char *a, char *b)
-{
-  fprintf (stderr, "InitBanner: can't %s %s\n", a, b);
-}
-
-
-
 /****************************************************************************
  *
- * Find the actual application 
- * 
+ * Find the actual application
+ *
  ***************************************************************************/
 Window
 ClientWindow (Window input)
